"""
Next-Generation Optimizations (2025)

Implementation of the latest optimization techniques:
- PyGraph CUDA Graph automation

These implementations represent the cutting edge of 2025 optimization research.
"""

from .pygraph_optimizer import (
    AutoGraphCapture,
    CUDAGraphManager,
    PyGraphOptimizer,
    SelectiveCUDAGraphs,
    create_pygraph_optimizer,
)

__all__ = [
    # PyGraph optimization
    'PyGraphOptimizer',
    'CUDAGraphManager',
    'AutoGraphCapture',
    'SelectiveCUDAGraphs',
    'create_pygraph_optimizer',
]
